/* author: Stéphane Laurent */
#ifndef UTILSHEADER
#define UTILSHEADER


int cmpfunc(const void*, const void*);
int cmpfuncdbl(const void*, const void*);
int cmpedges(const void*, const void*);
void qsortu(unsigned*, unsigned);

double square(double);

void appendu(unsigned, unsigned**, unsigned, unsigned*);

double* nanvector(int);

double* middle(double*, double*, unsigned);

double* getpoint(double*, unsigned, unsigned);

double dotproduct(double*, double*, unsigned);

unsigned* uzeros(unsigned);

double squaredDistance(double*, double*, unsigned);

unsigned equalarraysu(unsigned*, unsigned*, unsigned);

#endif
